#
# spec file for package lsp-plugins
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch %arm aarch64
%define _lto_cflags %{nil}
%endif
Name:           lsp-plugins
Version:        1.1.19
Release:        lp152.2.2
Summary:        Linux Studio Plugins Project (Stand-alone)
License:        LGPL-3.0-only AND Zlib
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://lsp-plug.in/
Source0:        https://github.com/sadko4u/lsp-plugins/archive/%{name}-%{version}.tar.gz#/%{name}-%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ladspa
BuildRequires:  ladspa-devel
BuildRequires:  php7-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(x11)
Requires:       %{name}-common = %{version}

%description
LSP (Linux Studio Plugins) is a collection of open-source plugins
currently compatible with LADSPA, LV2 and LinuxVST formats.

The basic idea is to fill the lack of good and useful plugins under
the GNU/Linux platform.

%package        common
Summary:        Linux Studio Plugins (Common files)
Group:          Productivity/Multimedia/Sound/Utilities

%description    common
Common files for lsp-plugins.

%package        doc
Summary:        Linux Studio Plugins Documents
Group:          Documentation/HTML

%description    doc
Documents for Linux Studio Plugins Project

%package -n     lv2-%{name}
Summary:        Linux Studio Plugins Documents (LV2)
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-common = %{version}

%description -n lv2-%{name}
LSP (Linux Studio Plugins) is a collection of open-source plugins
currently compatible with LADSPA, LV2 and LinuxVST formats.

The basic idea is to fill the lack of good and useful plugins under
the GNU/Linux platform.

This is the LV2 version of the plugins.

%package -n     vst-%{name}
Summary:        Linux Studio Plugins Documents (VST)
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-common = %{version}

%description -n vst-%{name}
LSP (Linux Studio Plugins) is a collection of open-source plugins
currently compatible with LADSPA, LV2 and LinuxVST formats.

The basic idea is to fill the lack of good and useful plugins under
the GNU/Linux platform.

This is the VST version of the plugins.

%package -n     ladspa-%{name}
Summary:        Linux Studio Plugins Documents (LADSPA)
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       %{name}-common = %{version}

%description -n ladspa-%{name}
LSP (Linux Studio Plugins) is a collection of open-source plugins
currently compatible with LADSPA, LV2 and LinuxVST formats.

The basic idea is to fill the lack of good and useful plugins under
the GNU/Linux platform.

This is the LADSPA version of the plugins.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
export PREFIX="%{_prefix}" DOC_PATH="%{_docdir}" LIB_PATH="%{_libdir}"
export CFLAGS="%{optflags}" CXXFLAGS="%{optflags}"
%make_build SHELL="$(which bash) -x"

%install
export PREFIX="%{_prefix}" DOC_PATH="%{_docdir}" LIB_PATH="%{_libdir}"
%make_install

for desktop in %{buildroot}%{_datadir}/applications/*.desktop; do
%suse_update_desktop_file ${desktop} Mixer
done

%fdupes -s %{buildroot}%{_libdir}

%files
%{_bindir}/%{name}-*
%dir %{_datadir}/applications
%dir %{_datadir}/desktop-directories
%dir %{_sysconfdir}/xdg
%dir %{_sysconfdir}/xdg/menus
%dir %{_sysconfdir}/xdg/menus/applications-merged
%{_datadir}/applications/*.desktop
%{_datadir}/desktop-directories/*
%exclude %{_datadir}/icons/hicolor/*
%config %{_sysconfdir}/xdg/menus/applications-merged/lsp-plugins.menu

%files common
%license LICENSE.txt
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{name}-jack-core-%{version}.so
%{_libdir}/%{name}/%{name}-r3d-glx.so

%files -n ladspa-%{name}
%{_libdir}/ladspa/%{name}-ladspa.so

%files -n lv2-%{name}
%dir %{_libdir}/lv2
%{_libdir}/lv2/%{name}.lv2

%files -n vst-%{name}
%dir %{_libdir}/vst
%{_libdir}/vst/%{name}-lxvst-%{version}

%files doc
%{_docdir}/%{name}

%changelog
* Wed Apr 29 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable LTO for %%arm and aarch64 to fix build
* Tue Apr 21 2020 andy great <andythe_great@pm.me>
- Update to 1.1.19
  * Updated XDG desktop application integration.
  * Refactoring of sse::fft functions for better portability
  between different compilation options.
  * Fixed bug in asimd::hdotp functions for AArch64 that caused
  invalid result output.
  * LV2 UI and standalone JACK plugins are now resizable.
  * Fixed plugin sizing issues on certain new Linux distributions.
  * Refactoring and several fixes of decoding and encoding of MIDI
  protocol messages.
  * Fixed silent MIDI output for JACK plugins.
  * Profile binaries are now excluded from release build.
- Remove lsp-plugins-fix_memory_corruption.patch
* Mon Apr  6 2020 andy great <andythe_great@pm.me>
- Update to 1.1.17.
* Thu Nov 28 2019 Luigi Baldoni <aloisio@gmx.com>
- Spec cleanup
* Tue Oct 29 2019 Fabio Pesari <fpesari@tuxfamily.org>
- Split various plugin formats into subpackages
* Tue Sep  3 2019 Luigi Baldoni <aloisio@gmx.com>
- Added lsp-plugins-fix_memory_corruption.patch
* Sun Aug 25 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.10
  * Implemented 3D reverb simulator plugin series - Room Builder
    Mono and Room Builder Stereo.
  * Fixed improper InlineDisplay feature support in LV2 TTL
    files.
  * Plugin names now have 'LSP' prefix for the LV2 format.
  * Each plugin can now provide it's custom UI class which is
    derived from common plugin's UI class.
  * Code now compiles for the PPC64 architecture.
  * Code now compiles for the IBM s390x architecture.
  * Added command-line option to pass configuration file name
    for standalone JACK plugins.
  * The settings stored in configuration file will be
    automatically loaded at startup.
  * Updated function signatures for libraries which now support
    '-fvisibility=hidden' compilation flag.
  * Added support of nested menus in the UI toolkit.
  * Added 3D scene rendering support in the UI by using
    different rendering backends.
  * Implemented GLX backend based on openGL 2.x for rendering 3D
    scenes.
  * Implemented key-value tree storage (KVTStorage) for storing
    and managing dynamic parameters.
  * Implemented key-value tree storage (KVTStorage) UI<->DSP
    synchronization mechanisms.
  * Implemented key-value tree storage (KVTStorage)
    serialization/deserialization in parameters.
  * Implemented key-value tree storage (KVTStorage)
    serialization/deserialization for the plugin state.
  * Implemented mechanism for UI<->DSP OSC message interchange.
  * Added support of OSC protocol messages serialization,
    deserialization and pattern matching.
  * Optimized complex number functions for AArch64 architecture.
  * Changed installation path for jack core library from to
    /lsp-plugins.
  * Added more careful file type analysis for non-EXT file
    systems.
  * Added support of Hygon Dhyana x86 family CPU optimizations
    and detection of some other CPU vendors.
  * Now both release and test binaries are available to build
    into separate subdirectories independently.
  * Improved built-in resource generation tool.
  * Embedded resources are now alphabetically sorted to make the
    build more deterministic.
  * Added support of built-in presets for plugin's UI.
- Dropped lsp-plugins-verbose.patch (using a different method to
  have verbose build)
- Enabled ppc64 build
* Sun Jun 30 2019 Jan Engelhardt <jengelh@inai.de>
- Put documentation into right group. Remove excess Requires.
* Fri Jun 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Improved lsp-plugins-verbose.patch
* Tue Jun 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.1.9
  * Added experimental support of AArch64 architecture (DSP code
    is not optimized yet).
  * Fixed regression in VST and Standalone plugin formats that
    caused offline tasks to not to be launched.
  * Improved build system to make source code possible to build
    for KXStudio repository.
    Distribution builders should ensure that the GNU C++
    compiler is selected at the build stage.
  * Additional I/O improvements for better WindowsNT support.
  version 1.1.7:
  * Implemented fully compatible with EqualizerAPO software
    digital filters that are now part of the Parametric Equalizer
    plugin series.
  * Fixed issue that caused VST plugins not to load from cusom
    user-defined path.
  * Some code parts rewritten for better compatibility with
    WindowsNT platform.
  * Fixed file listing in the file dialog that caused improper
    reading of remote directories mounted on the local file
    system.
  * Changed implementation of LV2 MIDI transport so now plugins
    utilize only one LV2:Atom input port and one LV2:Atom output
    port.
  * Fixed bug in host<->UI time and position synchronization for
    VST plugin format.
  * Fixed AVX+FMA3 implementation of dynamic biquadratic filters
    that caused improper behaviour of the Multi-band compressor
    plugin on machines that support AVX and FMA3 instruction set.
  * Multiband compressor now properly handles the 'Bypass'
    button.
  * Fixed return of improper extension pointers when requested
    extension is different to the ui:idleInterface.
  * Fixed bug in dynamic processor plugin that could issue
    invalid metering values.
  * Fixed UI size issue for VST plugins in Cockos Reaper.
  * Fixed numerous memory leakage issues in UI components.
  * Fixed spontaneous crashes when destroying the Profiler
    Mono/Stereo plugin.
  * Fixed embedded resource generation tool that had invalid
    behaviour for several file systems.
  * Reimplemented I/O subsystem.
- Dropped _service and fix-setting-paths.patch (no longer
  necessary)
- Added lsp-plugins-verbose.patch
* Fri Mar  8 2019 jthumshirn@suse.com
- Initial packaging for SUSE
  + fix-setting-paths.patch
